==> mshow-model-1.0.0.0-20190123.135346-33-sources.jar: com/mini/mshow/model/dbto/site/AccessTradeWeixinPayOrderDbto.java <==
package com.mini.mshow.model.dbto.site;

import com.mini.framework.model.dbto.style1.DbtoIntEntity;

/**
 * 微信的支付订单号
 * @author jayheo
 *
 */
public class AccessTradeWeixinPayOrderDbto extends DbtoIntEntity{

	/**
	 * 
	 */
	private static final long serialVersionUID = -802970837772577172L;
	
	
	/**
	 * 产品订单的id
	 */
	private Integer productOrderId;
	

	/**
	 * 商家侧的订单编号
	 */
	private String siteOrderNo;
	
	/**
	 * SUCCESS—支付成功
REFUND—转入退款
NOTPAY—未支付
CLOSED—已关闭
REVOKED—已撤销(刷卡支付)
USERPAYING--用户支付中
PAYERROR--支付失败(其他原因，如银行返回失败)
	 */
	private String weixinStatus;
	
	/**
	 * 用户支持的对象json
	 */
	private String payObjectJson;
	
	
	/**
	 * 用户支持的微信openid
	 */
	private String payOpenid;
	
	/**
	 *冗余 服务号id
	 */
	private String payAppid;
	
	/**
	 * 冗余付款用户id
	 */
	private Integer userId;
	
	/**
	 * 支付的金额
	 */
	private Integer payMoney;

	public Integer getProductOrderId() {
		return productOrderId;
	}

	public void setProductOrderId(Integer productOrderId) {
		this.productOrderId = productOrderId;
	}

	public String getSiteOrderNo() {
		return siteOrderNo;
	}

	public void setSiteOrderNo(String siteOrderNo) {
		this.siteOrderNo = siteOrderNo;
	}

	public String getWeixinStatus() {
		return weixinStatus;
	}

	public void setWeixinStatus(String weixinStatus) {
		this.weixinStatus = weixinStatus;
	}

	public String getPayObjectJson() {
		return payObjectJson;
	}

	public void setPayObjectJson(String payObjectJson) {
		this.payObjectJson = payObjectJson;
	}

	public String getPayOpenid() {
		return payOpenid;
	}

	public void setPayOpenid(String payOpenid) {
		this.payOpenid = payOpenid;
	}

	public String getPayAppid() {
		return payAppid;
	}

	public void setPayAppid(String payAppid) {
		this.payAppid = payAppid;
	}

	public Integer getUserId() {
		return userId;
	}

	public void setUserId(Integer userId) {
		this.userId = userId;
	}

	public Integer getPayMoney() {
		return payMoney;
	}

	public void setPayMoney(Integer payMoney) {
		this.payMoney = payMoney;
	}
	
	

}

==> mshow-model-1.0.0.0-20190307.121744-91-sources.jar: com/mini/mshow/model/dbto/site/AccessTradeWeixinPayOrderDbto.java <==
package com.mini.mshow.model.dbto.site;

import com.mini.framework.model.dbto.style1.DbtoIntEntity;
import com.mini.framework.util.date.DateStringFormatInc;

/**
 * 微信的支付订单号
 * @author jayheo
 *
 */
public class AccessTradeWeixinPayOrderDbto extends DbtoIntEntity{

	/**
	 * 
	 */
	private static final long serialVersionUID = -802970837772577172L;
	
	
	/**
	 * 产品订单的id
	 */
	private Integer productOrderId;
	

	/**
	 * 商家侧的订单编号
	 */
	private String siteOrderNo;
	
	/**
	 * SUCCESS—支付成功
REFUND—转入退款
NOTPAY—未支付
CLOSED—已关闭
REVOKED—已撤销(刷卡支付)
USERPAYING--用户支付中
PAYERROR--支付失败(其他原因，如银行返回失败)
	 */
	private String weixinStatus;
	
	/**
	 * 用户支持的对象json
	 */
	private String payObjectJson;
	
	
	/**
	 * 用户支持的微信openid
	 */
	private String payOpenid;
	
	/**
	 *冗余 服务号id
	 */
	private String payAppid;
	
	/**
	 * 冗余付款用户id
	 */
	private Integer userId;
	
	/**
	 * 支付的金额
	 */
	private Integer payMoney;

	public Integer getProductOrderId() {
		return productOrderId;
	}

	public void setProductOrderId(Integer productOrderId) {
		this.productOrderId = productOrderId;
	}

	public String getSiteOrderNo() {
		return siteOrderNo;
	}

	public void setSiteOrderNo(String siteOrderNo) {
		this.siteOrderNo = siteOrderNo;
	}

	public String getWeixinStatus() {
		return weixinStatus;
	}

	public void setWeixinStatus(String weixinStatus) {
		this.weixinStatus = weixinStatus;
	}

	public String getPayObjectJson() {
		return payObjectJson;
	}

	public void setPayObjectJson(String payObjectJson) {
		this.payObjectJson = payObjectJson;
	}

	public String getPayOpenid() {
		return payOpenid;
	}

	public void setPayOpenid(String payOpenid) {
		this.payOpenid = payOpenid;
	}

	public String getPayAppid() {
		return payAppid;
	}

	public void setPayAppid(String payAppid) {
		this.payAppid = payAppid;
	}

	public Integer getUserId() {
		return userId;
	}

	public void setUserId(Integer userId) {
		this.userId = userId;
	}

	public Integer getPayMoney() {
		return payMoney;
	}

	public void setPayMoney(Integer payMoney) {
		this.payMoney = payMoney;
	}
	
	
	public static DateStringFormatInc createWxpayOrder(){
		//ding wxpay微信支付 订单号
		return new  DateStringFormatInc("DW%s", "yyyyMMddHHmmss");
	}
	
	
}
